@@ -450,8 +450,12 @@ class TableWriter(object):
         x3 = os.system(command)
 
         if self.__path.fs_kind == "gcs":
-            for path in path_to_compile.with_suffix("").glob("*"):
+            glob_in = path_to_compile.parent
+            print("path_to_compile", path_to_compile)
+            for path in glob_in.glob(f"{path_to_compile.stem}*"):
                 path_gcs = self.__path.with_suffix(path.suffix)
+                print("  path", path)
+                print("  path_gcs", path_gcs)
                 path.put(path_gcs)
                 path.rm()
 
@@ -477,7 +481,7 @@ class TableWriter(object):
         to_keep = [".pdf", ".csv", ".excel"]
         if not clean_tex:
             to_keep.append(".tex")
-        files = self.__path.with_suffix("").glob("*")
+        files = self.__path.parent.glob(f"{self.__path.stem}*")
         for f in files:
             if f.suffix not in to_keep:
                 f.rm()
